DayCell class

A single cell widget of the calendar with the date

dateTime is the required field and the rest will only show a simple clean white background rounded border box with the date number inside

currentDay variable is select that cell by making it darker

You can always change the decorations of the cell by using cellDecorator or to change the currentDay decorator by currentDayDec isWeekend boolean will result on changing the decoration for the cell

Inheritance

Constructors

DayCell({Key? key, String number = '1', bool currentDay = false, bool selectedDay = false, bool isWeekend = false, bool dayInMonth = true, dynamic onTap(DateTime)?, CalendarCellDecorator? cellDecorator, bool showOutOfMonthCells = false, required DateTime dateTime, CalendarCellDecorator? currentDayDec})
const

Properties

cellDecorator CalendarCellDecorator?
final
currentDay bool
final
currentDayDec CalendarCellDecorator?
final
dateTime DateTime
final
dayInMonth bool
final
hashCode int
The hash code for this object.
no setterinherited
isWeekend bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
number String
final
onTap → dynamic Function(DateTime)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDay bool
final
showOutOfMonthCells bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DayCell>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited